@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: uuid-types
 version: 1.0.2
-id: uuid-types-1.0.2-e80dd8ed3b7ffef1dd40876281d96804
-key: uuidt_Kbofz3yQbJYIj1DO4WUJlu
+id: uuid-types-1.0.2-31d0afe3e94388f95aaba92ed882146a
+key: uuidt_9lrT22MidvP4pKCYa3dBVw
 license: BSD3
 copyright: (c) 2008-2014 Antoine Latter
 maintainer: aslatter@gmail.com
@@ -23,15 +23,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-types-1.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-types-1.0.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-types-1.0.2
-hs-libraries: HSuuid-types-1.0.2-Kbofz3yQbJYIj1DO4WUJlu
+hs-libraries: HSuuid-types-1.0.2-9lrT22MidvP4pKCYa3dBVw
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
 haddock-html: /usr/share/doc/haskell-uuid-types/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
